@@ -32,3 +32,10 @@ class BlackList(models.Model):
         managed = False
         verbose_name = 'Черный список'
         verbose_name_plural = 'Черный список'
+        constraints = (
+            models.UniqueConstraint(fields=('passport_serial', 'passport_number'),
+                                    condition=(~models.Q(passport_serial__exact='') &
+                                               ~models.Q(passport_number__exact='')),
+                                    name='unique_passport_black_list'),
+            models.UniqueConstraint(fields=('user_id',), condition=(~models.Q(user_id__exact='')), name='unique_user')
+                       )
