@@ -31,6 +31,10 @@ class Ext(models.Model):
     ip = models.GenericIPAddressField()
     http_referer = models.URLField('Реф. ссылка', blank=True, max_length=2048)
 
+    def set_department(self, department_id):
+        self.department_id = department_id
+        super().save()
+
     def __str__(self):
         return f'{self.user_id}'
 
