@@ -29,7 +29,7 @@ act = Act()
 
 
 def get_next_process_task(manager, process, user):
-    task = manager.filter(process=process, owner=user, status=STATUS.ASSIGNED).first()
+    task = manager.filter(process=process, owner=user.id, status=STATUS.ASSIGNED).first()
 
     # lookup for a task in a queue
     if task is None:
